==> chromium-54.0.2840.71.tar.xz: chromium-54.0.2840.71/chrome/browser/ui/webui/supervised_user_internals_ui.cc <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/ui/webui/supervised_user_internals_ui.h"

#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/ui/webui/supervised_user_internals_message_handler.h"
#include "chrome/common/url_constants.h"
#include "content/public/browser/web_ui.h"
#include "content/public/browser/web_ui_data_source.h"
#include "grit/browser_resources.h"

namespace {

content::WebUIDataSource* CreateSupervisedUserInternalsHTMLSource() {
  content::WebUIDataSource* source = content::WebUIDataSource::Create(
      chrome::kChromeUISupervisedUserInternalsHost);

  source->AddResourcePath("supervised_user_internals.js",
                          IDR_SUPERVISED_USER_INTERNALS_JS);
  source->AddResourcePath("supervised_user_internals.css",
                          IDR_SUPERVISED_USER_INTERNALS_CSS);
  source->SetDefaultResource(IDR_SUPERVISED_USER_INTERNALS_HTML);
  source->DisableI18nAndUseGzipForAllPaths();
  return source;
}

}  // namespace

SupervisedUserInternalsUI::SupervisedUserInternalsUI(content::WebUI* web_ui)
    : WebUIController(web_ui) {
  Profile* profile = Profile::FromWebUI(web_ui);
  content::WebUIDataSource::Add(profile,
                                CreateSupervisedUserInternalsHTMLSource());

  web_ui->AddMessageHandler(new SupervisedUserInternalsMessageHandler);
}

SupervisedUserInternalsUI::~SupervisedUserInternalsUI() {}

==> chromium-55.0.2883.76.tar.xz: chromium-55.0.2883.76/chrome/browser/ui/webui/supervised_user_internals_ui.cc <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "chrome/browser/ui/webui/supervised_user_internals_ui.h"

#include "chrome/browser/profiles/profile.h"
#include "chrome/browser/ui/webui/supervised_user_internals_message_handler.h"
#include "chrome/common/url_constants.h"
#include "chrome/grit/browser_resources.h"
#include "content/public/browser/web_ui.h"
#include "content/public/browser/web_ui_data_source.h"

namespace {

content::WebUIDataSource* CreateSupervisedUserInternalsHTMLSource() {
  content::WebUIDataSource* source = content::WebUIDataSource::Create(
      chrome::kChromeUISupervisedUserInternalsHost);

  source->AddResourcePath("supervised_user_internals.js",
                          IDR_SUPERVISED_USER_INTERNALS_JS);
  source->AddResourcePath("supervised_user_internals.css",
                          IDR_SUPERVISED_USER_INTERNALS_CSS);
  source->SetDefaultResource(IDR_SUPERVISED_USER_INTERNALS_HTML);
  source->DisableI18nAndUseGzipForAllPaths();
  return source;
}

}  // namespace

SupervisedUserInternalsUI::SupervisedUserInternalsUI(content::WebUI* web_ui)
    : WebUIController(web_ui) {
  Profile* profile = Profile::FromWebUI(web_ui);
  content::WebUIDataSource::Add(profile,
                                CreateSupervisedUserInternalsHTMLSource());

  web_ui->AddMessageHandler(new SupervisedUserInternalsMessageHandler);
}

SupervisedUserInternalsUI::~SupervisedUserInternalsUI() {}
